summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/beam.cc
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/beam.cc')
-rw-r--r--crawl-ref/source/beam.cc6
1 files changed, 5 insertions, 1 deletions
diff --git a/crawl-ref/source/beam.cc b/crawl-ref/source/beam.cc
index d38fc3f648..206ebcf2c7 100644
--- a/crawl-ref/source/beam.cc
+++ b/crawl-ref/source/beam.cc
@@ -5348,7 +5348,11 @@ void bolt::determine_affected_cells(explosion_map& m, const coord_def& delta,
// straightforward.
bool bolt::nasty_to(const monsters *mon) const
{
- // Take care of non-enchantments.
+ // Cleansing flame.
+ if (flavour == BEAM_HOLY)
+ return (mon->res_cleansing_flame(agent()) <= 0);
+
+ // Take care of other non-enchantments.
if (!is_enchantment())
return (true);